==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/es.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Documentos",
    "Can't create document" : "No es posible crear el documento",
    "You don't have permission to rename this document" : "No tiene permiso para cambiar de nombre a este documento",
    "Directory saved successfully." : "Directorio guardado con éxito.",
    "An error occurred while changing directory." : "Se produjo un error mientras se cambiaba el directorio.",
    "Saved" : "Guardado",
    "Format filter server is down or misconfigured" : "El filtro de formato del servidor está caído o desconfigurado",
    "Conversion failed. Check log for details." : "La conversión falló. Para más detalles, revise el registro.",
    "document-styles" : "estilos de documento",
    "document-content" : "contenido de documento",
    "bold" : "negrita",
    "italic" : "cursiva",
    "solid" : "sólido",
    "pt" : "pt",
    "Saving..." : "Guardando...",
    "Failed to load documents." : "Error al cargar los documentos.",
    "No documents were found. Upload or create a document to get started!" : "No se encontraron documentos. ¡Suba o cree un documento para comenzar!",
    "No connection to server. Trying to reconnect." : "No hay conexión con el servidor. Intentando reconectar.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Si deja esta página en el modo de edición, puede que algunos datos no sean guardados. Es preferible usar el botón «Cerrar».",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "No se pudo cargar el documento. Sírvase comprobar si puede abrirlo con un editor de archivos ODT externo. También puede ser que hayan dejado de compartirlo o haya sido eliminado recientemente.",
    "Save" : "Guardar",
    "Loading documents..." : "Cargando los documentos...",
    "'.' is an invalid file name." : "'.' no es un nombre de archivo válido.",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nombre inválido, los caracteres \"\\\", \"/\", \"<\", \">\", \":\", \"\", \"|\" \"?\" y \"*\" no están permitidos ",
    "Align Left" : "Alinear a la izquierda",
    "Alignment" : "Alineación",
    "Align Right" : "Alinear a la derecha",
    "Annotate" : "Anotar",
    "Background" : "Fondo",
    "Bold" : "Negrita",
    "Bottom" : "Inferior",
    "Cancel" : "Cancelar",
    "Center" : "Centrado",
    "Clone" : "Clonar",
    "Clone this Style" : "Clonar este estilo",
    "Close" : "Cerrar",
    "Color" : "Color",
    "Create" : "Crear",
    "Decrease Indent" : "Disminuir sangría",
    "Default Style" : "Estilo por defecto",
    "Delete" : "Eliminar",
    "Family" : "Familia",
    "Font" : "Fuente",
    "Font Effects" : "Efectos de fuente",
    "Format" : "Formato",
    "Increase Indent" : "Aumentar sangría",
    "Insert Image" : "Insertar una imagen",
    "Invite Members" : "Invitar a miembros",
    "Italic" : "Cursiva",
    "Justified" : "Justificado",
    "Justify" : "Justificar",
    "Left" : "Izquierda",
    "Loading" : "Cargando",
    "Members" : "Miembros",
    "New Name:" : "Nuevo nombre",
    "OK" : "Aceptar",
    "Open" : "Abrir",
    "Options" : "Opciones",
    "Paragraph..." : "Parrafo",
    "Paragraph Styles" : "Estilos de párrafo",
    "Redo" : "Rehacer",
    "Right" : "Derecho",
    "Size" : "Tamaño",
    "Spacing" : "Espaciamiento",
    "Strikethrough" : "Tachado",
    "Style" : "Estilo",
    "Text" : "Texto",
    "Top" : "Superior",
    "Underline" : "Subrayado",
    "Undo" : "Deshacer",
    "Unknown Author" : "Autor desconocido",
    "Edit" : "Editar",
    "Share" : "Compartir",
    "guest" : "invitado",
    "MS Word support (requires openOffice/libreOffice)" : "Soporte de MS Word (requiere OpenOffice/LibreOffice)",
    "Local" : "Local",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice está instalado en este servidor. La ruta a los binarios está en el archivo config.php en la entrada preview_libreoffice_path",
    "External" : "Externo",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice está instalado en un servidor externo ejecutando un filtro de formato",
    "Disabled" : "Deshabilitado",
    "No MS Word support" : "Sin soporte para MS Word",
    "scheme://domain.tld[:port]" : "Esquema://dominio.tld[:puerto]",
    "Server URL" : "URL del servidor",
    "Apply and test" : "Aplicar y probar",
    "New document" : "Nuevo documento",
    "Upload (max. %s)" : "Subida (máx. %s)",
    "Upload" : "Subir",
    "Save new documents to" : "Guardar nuevos documentos en",
    "Wrong password. Please retry." : "Contraseña incorrecta. Inténtelo de nuevo.",
    "Password" : "Contraseña",
    "Guest %s" : "Invitado %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Este enlace caducó o nunca existió. Para más detalles, sírvase contactar a la persona que lo compartió con usted.",
    "Advanced feature-set" : "Características avanzadas",
    "(Unstable)" : "(Inestable)"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/es.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Documentos",
    "Can't create document" : "No es posible crear el documento",
    "You don't have permission to rename this document" : "No tiene permiso para cambiar de nombre a este documento",
    "File does not exist" : "El archivo no existe",
    "Directory saved successfully." : "Directorio guardado con éxito.",
    "An error occurred while changing directory." : "Se produjo un error mientras se cambiaba el directorio.",
    "Saved" : "Guardado",
    "Format filter server is down or misconfigured" : "El filtro de formato del servidor está caído o desconfigurado",
    "Conversion failed. Check log for details." : "La conversión falló. Para más detalles, revise el registro.",
    "Saving..." : "Guardando...",
    "Failed to load documents." : "Error al cargar los documentos.",
    "No documents were found. Upload or create a document to get started!" : "No se encontraron documentos. ¡Suba o cree un documento para comenzar!",
    "No connection to server. Trying to reconnect." : "No hay conexión con el servidor. Intentando reconectar.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Si deja esta página en el modo de edición, puede que algunos datos no sean guardados. Es preferible usar el botón «Cerrar».",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "No se pudo cargar el documento. Sírvase comprobar si puede abrirlo con un editor de archivos ODT externo. También puede ser que hayan dejado de compartirlo o haya sido eliminado recientemente.",
    "Save" : "Guardar",
    "Loading documents..." : "Cargando los documentos...",
    "'.' is an invalid file name." : "'.' no es un nombre de archivo válido.",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nombre inválido, los caracteres \"\\\", \"/\", \"<\", \">\", \":\", \"\", \"|\" \"?\" y \"*\" no están permitidos ",
    "Align Left" : "Alinear a la izquierda",
    "Alignment" : "Alineación",
    "Align Right" : "Alinear a la derecha",
    "Annotate" : "Anotar",
    "Background" : "Fondo",
    "Bold" : "Negrita",
    "Bottom" : "Inferior",
    "Cancel" : "Cancelar",
    "Center" : "Centrado",
    "Clone" : "Clonar",
    "Clone this Style" : "Clonar este estilo",
    "Close" : "Cerrar",
    "Color" : "Color",
    "Create" : "Crear",
    "Decrease Indent" : "Disminuir sangría",
    "Default Style" : "Estilo por defecto",
    "Delete" : "Eliminar",
    "Family" : "Familia",
    "Font" : "Fuente",
    "Font Effects" : "Efectos de fuente",
    "Format" : "Formato",
    "Increase Indent" : "Aumentar sangría",
    "Insert Image" : "Insertar una imagen",
    "Invite Members" : "Invitar a miembros",
    "Italic" : "Cursiva",
    "Justified" : "Justificado",
    "Justify" : "Justificar",
    "Left" : "Izquierda",
    "Loading" : "Cargando",
    "Members" : "Miembros",
    "New Name:" : "Nuevo nombre",
    "OK" : "Aceptar",
    "Open" : "Abrir",
    "Options" : "Opciones",
    "Paragraph..." : "Parrafo",
    "Paragraph Styles" : "Estilos de párrafo",
    "Redo" : "Rehacer",
    "Right" : "Derecho",
    "Size" : "Tamaño",
    "Spacing" : "Espaciamiento",
    "Strikethrough" : "Tachado",
    "Style" : "Estilo",
    "Text" : "Texto",
    "Top" : "Superior",
    "Underline" : "Subrayado",
    "Undo" : "Deshacer",
    "Unknown Author" : "Autor desconocido",
    "Shared" : "Compartido",
    "Error" : "Error",
    "Error while sharing" : "Error al compartir",
    "Error while unsharing" : "Error al dejar de compartir",
    "Error while changing permissions" : "Error al cambiar permisos",
    "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido contigo por {owner}",
    "Share with users or groups …" : "Compartir con usuarios o grupos ...",
    "Share with users, groups or remote users …" : "Comparte con usuarios, grupos o usuarios remotos...",
    "Share" : "Compartir",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Comparta con personas en otros ownClouds utilizando la sintáxis username@example.com/owncloud",
    "Share link" : "Compartir enlace",
    "The public link will expire no later than {days} days after it is created" : "El vínculo público no expirará antes de {days} desde que se creó",
    "Link" : "Enlace",
    "Password protect" : "Protección con contraseña",
    "Password" : "Contraseña",
    "Choose a password for the public link" : "Elija una contraseña para el enlace publico",
    "Allow editing" : "Permitir edición",
    "Email link to person" : "Enviar enlace por correo electrónico a una persona",
    "Send" : "Enviar",
    "Set expiration date" : "Establecer fecha de caducidad",
    "Expiration" : "Expira en:",
    "Expiration date" : "Fecha de caducidad",
    "An error occured. Please try again" : "Ocurrió un error. Por favor, reinténtelo nuevamente.",
    "Adding user..." : "Añadiendo usuario...",
    "group" : "grupo",
    "remote" : "remoto",
    "Resharing is not allowed" : "No se permite compartir de nuevo",
    "Shared in {item} with {user}" : "Compartido en {item} con {user}",
    "Unshare" : "Dejar de compartir",
    "notify by email" : "notificar por correo electrónico",
    "can share" : "puede compartir",
    "can edit" : "puede editar",
    "access control" : "control de acceso",
    "create" : "crear",
    "change" : "cambio",
    "delete" : "borrar",
    "Password protected" : "Protegido con contraseña",
    "Error unsetting expiration date" : "Error al destablecer la fecha de caducidad",
    "Error setting expiration date" : "Error estableciendo fecha de caducidad",
    "Sending ..." : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Warning" : "Precaución",
    "Edit" : "Editar",
    "guest" : "invitado",
    "MS Word support (requires openOffice/libreOffice)" : "Soporte de MS Word (requiere OpenOffice/LibreOffice)",
    "Local" : "Local",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice está instalado en este servidor. La ruta a los binarios está en el archivo config.php en la entrada preview_libreoffice_path",
    "External" : "Externo",
    "openOffice/libreOffice is installed on external server running a format filter server" : "OpenOffice/LibreOffice está instalado en un servidor externo ejecutando un filtro de formato",
    "Disabled" : "Deshabilitado",
    "No MS Word support" : "Sin soporte para MS Word",
    "scheme://domain.tld[:port]" : "Esquema://dominio.tld[:puerto]",
    "Server URL" : "URL del servidor",
    "Apply and test" : "Aplicar y probar",
    "New document" : "Nuevo documento",
    "Upload (max. %s)" : "Subida (máx. %s)",
    "Upload" : "Subir",
    "Save new documents to" : "Guardar nuevos documentos en",
    "Wrong password. Please retry." : "Contraseña incorrecta. Inténtelo de nuevo.",
    "Guest %s" : "Invitado %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Este enlace caducó o nunca existió. Para más detalles, sírvase contactar a la persona que lo compartió con usted.",
    "Advanced feature-set" : "Características avanzadas",
    "(Unstable)" : "(Inestable)"
},
"nplurals=2; plural=(n != 1);");
